Commands#

Target

What it does

bazel run //:docs

Builds documentation

bazel run //:docs_check

Verifies documentation correctness

bazel run //:docs_combo

Builds combined documentation with all external dependencies included

bazel run //scripts_bazel:traceability_coverage -- --needs-json bazel-bin/needs_json/needs.json --min-req-code 100 --min-req-test 100 --min-req-fully-linked 100 --min-tests-linked 100 --fail-on-broken-test-refs

Calculates requirement/test traceability percentages and fails if thresholds are not met

bazel run //:live_preview

Creates a live_preview of the documentation viewable in a local server

bazel run //:live_preview_combo_experimental

Creates a live_preview of the full documentation with all dependencies viewable in a local server

bazel run //:ide_support

Sets up a Python venv for esbonio (Remember to restart VS Code!)

Internal targets (do not use directly)#

Target

What it does

bazel build //:needs_json

Creates a ‘needs.json’ file

bazel build //:docs_sources

Provides all the documentation source files